! $Id: ColourValues.f90 2112 2016-05-11 01:12:30Z ian $
! Copyright 2016 M.E.G.M.S.  See LICENCE.txt for licence (Apache 2.0).

!> @file
!! Defines the ColourValues module.


!*******************************************************************************
!!
!> Defines packed RGB constants for the commonly used colour schemes.

MODULE ColourValues
  
  IMPLICIT NONE
  
  ! Avoid these accidentally leaking out.
  PRIVATE :: SELECTED_INT_KIND
  PRIVATE :: INT
  
  !-----------------------------------------------------------------------------
  
  !> Kind parameter for the colours.
  INTEGER, PARAMETER :: ik = SELECTED_INT_KIND(7)
  
  !> Mask required to access the red component.
  INTEGER(ik), PARAMETER :: r_m = INT(Z'FF0000', ik)
  !> Mask required to access the green component.
  INTEGER(ik), PARAMETER :: g_m = INT(Z'00FF00', ik)
  !> Mask required to access the blue component.
  INTEGER(ik), PARAMETER :: b_m = INT(Z'0000FF', ik)
  
  !> Shift required to access the red component.
  INTEGER(ik), PARAMETER :: r_s = 16
  !> Shift required to access the green component.
  INTEGER(ik), PARAMETER :: g_s = 8
  !> Shift required to access the blue component.
  INTEGER(ik), PARAMETER :: b_s = 0
  
  ! The packed calues for each colour.  Note that we duplicate to cover 
  ! altenative spellings of Gray and Grey.
  
  ! These names are consistent (with one exception) across Direct2D, SVG, 
  ! Gdiplus
  ! The draft C++ 2D graphics proposal uses underbar as a word separator.
  !
  INTEGER(ik), PARAMETER :: v_AliceBlue             = INT(Z'F0F8FF', ik)
  INTEGER(ik), PARAMETER :: v_AntiqueWhite          = INT(Z'FAEBD7', ik)
  INTEGER(ik), PARAMETER :: v_Aqua                  = INT(Z'00FFFF', ik)
  INTEGER(ik), PARAMETER :: v_Aquamarine            = INT(Z'7FFFD4', ik)
  INTEGER(ik), PARAMETER :: v_Azure                 = INT(Z'F0FFFF', ik)
  INTEGER(ik), PARAMETER :: v_Beige                 = INT(Z'F5F5DC', ik)
  INTEGER(ik), PARAMETER :: v_Bisque                = INT(Z'FFE4C4', ik)
  INTEGER(ik), PARAMETER :: v_Black                 = INT(Z'000000', ik)
  INTEGER(ik), PARAMETER :: v_BlanchedAlmond        = INT(Z'FFEBCD', ik)
  INTEGER(ik), PARAMETER :: v_Blue                  = INT(Z'0000FF', ik)
  INTEGER(ik), PARAMETER :: v_BlueViolet            = INT(Z'8A2BE2', ik)
  INTEGER(ik), PARAMETER :: v_Brown                 = INT(Z'A52A2A', ik)
  INTEGER(ik), PARAMETER :: v_BurlyWood             = INT(Z'DEB887', ik)
  INTEGER(ik), PARAMETER :: v_CadetBlue             = INT(Z'5F9EA0', ik)
  INTEGER(ik), PARAMETER :: v_Chartreuse            = INT(Z'7FFF00', ik)
  INTEGER(ik), PARAMETER :: v_Chocolate             = INT(Z'D2691E', ik)
  INTEGER(ik), PARAMETER :: v_Coral                 = INT(Z'FF7F50', ik)
  INTEGER(ik), PARAMETER :: v_CornflowerBlue        = INT(Z'6495ED', ik)
  INTEGER(ik), PARAMETER :: v_Cornsilk              = INT(Z'FFF8DC', ik)
  INTEGER(ik), PARAMETER :: v_Crimson               = INT(Z'DC143C', ik)
  INTEGER(ik), PARAMETER :: v_Cyan                  = INT(Z'00FFFF', ik)
  INTEGER(ik), PARAMETER :: v_DarkBlue              = INT(Z'00008B', ik)
  INTEGER(ik), PARAMETER :: v_DarkCyan              = INT(Z'008B8B', ik)
  INTEGER(ik), PARAMETER :: v_DarkGoldenrod         = INT(Z'B8860B', ik)
  INTEGER(ik), PARAMETER :: v_DarkGray              = INT(Z'A9A9A9', ik)
  INTEGER(ik), PARAMETER :: v_DarkGrey              = v_DarkGray
  INTEGER(ik), PARAMETER :: v_DarkGreen             = INT(Z'006400', ik)
  INTEGER(ik), PARAMETER :: v_DarkKhaki             = INT(Z'BDB76B', ik)
  INTEGER(ik), PARAMETER :: v_DarkMagenta           = INT(Z'8B008B', ik)
  INTEGER(ik), PARAMETER :: v_DarkOliveGreen        = INT(Z'556B2F', ik)
  INTEGER(ik), PARAMETER :: v_DarkOrange            = INT(Z'FF8C00', ik)
  INTEGER(ik), PARAMETER :: v_DarkOrchid            = INT(Z'9932CC', ik)
  INTEGER(ik), PARAMETER :: v_DarkRed               = INT(Z'8B0000', ik)
  INTEGER(ik), PARAMETER :: v_DarkSalmon            = INT(Z'E9967A', ik)
  ! Gdiplus 8FBC8B
  INTEGER(ik), PARAMETER :: v_DarkSeaGreen          = INT(Z'8FBC8F', ik)
  INTEGER(ik), PARAMETER :: v_DarkSlateBlue         = INT(Z'483D8B', ik)
  INTEGER(ik), PARAMETER :: v_DarkSlateGray         = INT(Z'2F4F4F', ik)
  INTEGER(ik), PARAMETER :: v_DarkSlateGrey         = v_DarkSlateGray
  INTEGER(ik), PARAMETER :: v_DarkTurquoise         = INT(Z'00CED1', ik)
  INTEGER(ik), PARAMETER :: v_DarkViolet            = INT(Z'9400D3', ik)
  INTEGER(ik), PARAMETER :: v_DeepPink              = INT(Z'FF1493', ik)
  INTEGER(ik), PARAMETER :: v_DeepSkyBlue           = INT(Z'00BFFF', ik)
  INTEGER(ik), PARAMETER :: v_DimGray               = INT(Z'696969', ik)
  INTEGER(ik), PARAMETER :: v_DimGrey               = v_DimGray
  INTEGER(ik), PARAMETER :: v_DodgerBlue            = INT(Z'1E90FF', ik)
  INTEGER(ik), PARAMETER :: v_Firebrick             = INT(Z'B22222', ik)
  INTEGER(ik), PARAMETER :: v_FloralWhite           = INT(Z'FFFAF0', ik)
  INTEGER(ik), PARAMETER :: v_ForestGreen           = INT(Z'228B22', ik)
  INTEGER(ik), PARAMETER :: v_Fuchsia               = INT(Z'FF00FF', ik)
  INTEGER(ik), PARAMETER :: v_Gainsboro             = INT(Z'DCDCDC', ik)
  INTEGER(ik), PARAMETER :: v_GhostWhite            = INT(Z'F8F8FF', ik)
  INTEGER(ik), PARAMETER :: v_Gold                  = INT(Z'FFD700', ik)
  INTEGER(ik), PARAMETER :: v_Goldenrod             = INT(Z'DAA520', ik)
  INTEGER(ik), PARAMETER :: v_Gray                  = INT(Z'808080', ik)
  INTEGER(ik), PARAMETER :: v_Grey                  = v_Gray
  INTEGER(ik), PARAMETER :: v_Green                 = INT(Z'008000', ik)
  INTEGER(ik), PARAMETER :: v_GreenYellow           = INT(Z'ADFF2F', ik)
  INTEGER(ik), PARAMETER :: v_Honeydew              = INT(Z'F0FFF0', ik)
  INTEGER(ik), PARAMETER :: v_HotPink               = INT(Z'FF69B4', ik)
  INTEGER(ik), PARAMETER :: v_IndianRed             = INT(Z'CD5C5C', ik)
  INTEGER(ik), PARAMETER :: v_Indigo                = INT(Z'4B0082', ik)
  INTEGER(ik), PARAMETER :: v_Ivory                 = INT(Z'FFFFF0', ik)
  INTEGER(ik), PARAMETER :: v_Khaki                 = INT(Z'F0E68C', ik)
  INTEGER(ik), PARAMETER :: v_Lavender              = INT(Z'E6E6FA', ik)
  INTEGER(ik), PARAMETER :: v_LavenderBlush         = INT(Z'FFF0F5', ik)
  INTEGER(ik), PARAMETER :: v_LawnGreen             = INT(Z'7CFC00', ik)
  INTEGER(ik), PARAMETER :: v_LemonChiffon          = INT(Z'FFFACD', ik)
  INTEGER(ik), PARAMETER :: v_LightBlue             = INT(Z'ADD8E6', ik)
  INTEGER(ik), PARAMETER :: v_LightCoral            = INT(Z'F08080', ik)
  INTEGER(ik), PARAMETER :: v_LightCyan             = INT(Z'E0FFFF', ik)
  INTEGER(ik), PARAMETER :: v_LightGoldenrodYellow  = INT(Z'FAFAD2', ik)
  INTEGER(ik), PARAMETER :: v_LightGray             = INT(Z'D3D3D3', ik)
  INTEGER(ik), PARAMETER :: v_LightGrey             = v_LightGray
  INTEGER(ik), PARAMETER :: v_LightGreen            = INT(Z'90EE90', ik)
  INTEGER(ik), PARAMETER :: v_LightPink             = INT(Z'FFB6C1', ik)
  INTEGER(ik), PARAMETER :: v_LightSalmon           = INT(Z'FFA07A', ik)
  INTEGER(ik), PARAMETER :: v_LightSeaGreen         = INT(Z'20B2AA', ik)
  INTEGER(ik), PARAMETER :: v_LightSkyBlue          = INT(Z'87CEFA', ik)
  INTEGER(ik), PARAMETER :: v_LightSlateGray        = INT(Z'778899', ik)
  INTEGER(ik), PARAMETER :: v_LightSlateGrey        = v_LightSlateGray
  INTEGER(ik), PARAMETER :: v_LightSteelBlue        = INT(Z'B0C4DE', ik)
  INTEGER(ik), PARAMETER :: v_LightYellow           = INT(Z'FFFFE0', ik)
  INTEGER(ik), PARAMETER :: v_Lime                  = INT(Z'00FF00', ik)
  INTEGER(ik), PARAMETER :: v_LimeGreen             = INT(Z'32CD32', ik)
  INTEGER(ik), PARAMETER :: v_Linen                 = INT(Z'FAF0E6', ik)
  INTEGER(ik), PARAMETER :: v_Magenta               = INT(Z'FF00FF', ik)
  INTEGER(ik), PARAMETER :: v_Maroon                = INT(Z'800000', ik)
  INTEGER(ik), PARAMETER :: v_MediumAquamarine      = INT(Z'66CDAA', ik)
  INTEGER(ik), PARAMETER :: v_MediumBlue            = INT(Z'0000CD', ik)
  INTEGER(ik), PARAMETER :: v_MediumOrchid          = INT(Z'BA55D3', ik)
  INTEGER(ik), PARAMETER :: v_MediumPurple          = INT(Z'9370DB', ik)
  INTEGER(ik), PARAMETER :: v_MediumSeaGreen        = INT(Z'3CB371', ik)
  INTEGER(ik), PARAMETER :: v_MediumSlateBlue       = INT(Z'7B68EE', ik)
  INTEGER(ik), PARAMETER :: v_MediumSpringGreen     = INT(Z'00FA9A', ik)
  INTEGER(ik), PARAMETER :: v_MediumTurquoise       = INT(Z'48D1CC', ik)
  INTEGER(ik), PARAMETER :: v_MediumVioletRed       = INT(Z'C71585', ik)
  INTEGER(ik), PARAMETER :: v_MidnightBlue          = INT(Z'191970', ik)
  INTEGER(ik), PARAMETER :: v_MintCream             = INT(Z'F5FFFA', ik)
  INTEGER(ik), PARAMETER :: v_MistyRose             = INT(Z'FFE4E1', ik)
  INTEGER(ik), PARAMETER :: v_Moccasin              = INT(Z'FFE4B5', ik)
  INTEGER(ik), PARAMETER :: v_NavajoWhite           = INT(Z'FFDEAD', ik)
  INTEGER(ik), PARAMETER :: v_Navy                  = INT(Z'000080', ik)
  INTEGER(ik), PARAMETER :: v_OldLace               = INT(Z'FDF5E6', ik)
  INTEGER(ik), PARAMETER :: v_Olive                 = INT(Z'808000', ik)
  INTEGER(ik), PARAMETER :: v_OliveDrab             = INT(Z'6B8E23', ik)
  INTEGER(ik), PARAMETER :: v_Orange                = INT(Z'FFA500', ik)
  INTEGER(ik), PARAMETER :: v_OrangeRed             = INT(Z'FF4500', ik)
  INTEGER(ik), PARAMETER :: v_Orchid                = INT(Z'DA70D6', ik)
  INTEGER(ik), PARAMETER :: v_PaleGoldenrod         = INT(Z'EEE8AA', ik)
  INTEGER(ik), PARAMETER :: v_PaleGreen             = INT(Z'98FB98', ik)
  INTEGER(ik), PARAMETER :: v_PaleTurquoise         = INT(Z'AFEEEE', ik)
  INTEGER(ik), PARAMETER :: v_PaleVioletRed         = INT(Z'DB7093', ik)
  INTEGER(ik), PARAMETER :: v_PapayaWhip            = INT(Z'FFEFD5', ik)
  INTEGER(ik), PARAMETER :: v_PeachPuff             = INT(Z'FFDAB9', ik)
  INTEGER(ik), PARAMETER :: v_Peru                  = INT(Z'CD853F', ik)
  INTEGER(ik), PARAMETER :: v_Pink                  = INT(Z'FFC0CB', ik)
  INTEGER(ik), PARAMETER :: v_Plum                  = INT(Z'DDA0DD', ik)
  INTEGER(ik), PARAMETER :: v_PowderBlue            = INT(Z'B0E0E6', ik)
  INTEGER(ik), PARAMETER :: v_Purple                = INT(Z'800080', ik)
  INTEGER(ik), PARAMETER :: v_Red                   = INT(Z'FF0000', ik)
  INTEGER(ik), PARAMETER :: v_RosyBrown             = INT(Z'BC8F8F', ik)
  INTEGER(ik), PARAMETER :: v_RoyalBlue             = INT(Z'4169E1', ik)
  INTEGER(ik), PARAMETER :: v_SaddleBrown           = INT(Z'8B4513', ik)
  INTEGER(ik), PARAMETER :: v_Salmon                = INT(Z'FA8072', ik)
  INTEGER(ik), PARAMETER :: v_SandyBrown            = INT(Z'F4A460', ik)
  INTEGER(ik), PARAMETER :: v_SeaGreen              = INT(Z'2E8B57', ik)
  INTEGER(ik), PARAMETER :: v_SeaShell              = INT(Z'FFF5EE', ik)
  INTEGER(ik), PARAMETER :: v_Sienna                = INT(Z'A0522D', ik)
  INTEGER(ik), PARAMETER :: v_Silver                = INT(Z'C0C0C0', ik)
  INTEGER(ik), PARAMETER :: v_SkyBlue               = INT(Z'87CEEB', ik)
  INTEGER(ik), PARAMETER :: v_SlateBlue             = INT(Z'6A5ACD', ik)
  INTEGER(ik), PARAMETER :: v_SlateGray             = INT(Z'708090', ik)
  INTEGER(ik), PARAMETER :: v_SlateGrey             = v_SlateGray
  INTEGER(ik), PARAMETER :: v_Snow                  = INT(Z'FFFAFA', ik)
  INTEGER(ik), PARAMETER :: v_SpringGreen           = INT(Z'00FF7F', ik)
  INTEGER(ik), PARAMETER :: v_SteelBlue             = INT(Z'4682B4', ik)
  INTEGER(ik), PARAMETER :: v_Tan                   = INT(Z'D2B48C', ik)
  INTEGER(ik), PARAMETER :: v_Teal                  = INT(Z'008080', ik)
  INTEGER(ik), PARAMETER :: v_Thistle               = INT(Z'D8BFD8', ik)
  INTEGER(ik), PARAMETER :: v_Tomato                = INT(Z'FF6347', ik)
  INTEGER(ik), PARAMETER :: v_Turquoise             = INT(Z'40E0D0', ik)
  INTEGER(ik), PARAMETER :: v_Violet                = INT(Z'EE82EE', ik)
  INTEGER(ik), PARAMETER :: v_Wheat                 = INT(Z'F5DEB3', ik)
  INTEGER(ik), PARAMETER :: v_White                 = INT(Z'FFFFFF', ik)
  INTEGER(ik), PARAMETER :: v_WhiteSmoke            = INT(Z'F5F5F5', ik)
  INTEGER(ik), PARAMETER :: v_Yellow                = INT(Z'FFFF00', ik)
  INTEGER(ik), PARAMETER :: v_YellowGreen           = INT(Z'9ACD32', ik)
  
END MODULE ColourValues
